#!/bin/bash
echo "Backing up Keycloak DB and config"


DIR=$(realpath $(dirname $0))

if [ ! -e $DIR/.env ]
then
    echo ".env file do not exist"
    exit 1
fi

. $DIR/.env

if [ -z "$MARIADB_PASS" ]; then
  echo "Error: the MARIADB_PASS variable is not set or is empty."
  exit 1
fi

mkdir -p $DIR/backups

out="$DIR/backups/keycloak_$(date +%Y%m%d_%H%M).tar.gz"

if command -v docker-compose &> /dev/null; then
    DOCKER_COMPOSE="docker-compose"
elif docker compose version &> /dev/null; then
    DOCKER_COMPOSE="docker compose"
else
    echo "'docker compose' and 'docker-compose' not found"
    exit 1
fi

$DOCKER_COMPOSE exec -T mariadb mysqldump --all-databases -u root -p"$MARIADB_PASS" --default-character-set=utf8 | gzip > "$out"

ls -lh $out
echo "Done"
